@@ -53,16 +53,15 @@ def test_invalid_id():
 def test_invalid_age():
     result = runner.invoke(app, ["5", "--age", "15"])
     assert result.exit_code != 0
-    assert "Invalid value for '--age': 15 is not in the range x>=18" in result.output
+    assert "Invalid value for '--age'" in result.output
+    assert "15 is not in the range x>=18" in result.output
 
 
 def test_invalid_score():
     result = runner.invoke(app, ["5", "--age", "20", "--score", "100.5"])
     assert result.exit_code != 0
-    assert (
-        "Invalid value for '--score': 100.5 is not in the range x<=100."
-        in result.output
-    )
+    assert "Invalid value for '--score'" in result.output
+    assert "100.5 is not in the range x<=100." in result.output
 
 
 def test_negative_score():
